<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">リピート: 全て</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">リピート: トラック</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">再生ストリーム.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">バッファーストリーム.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">ストリーム一時停止.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">出力エラー.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">ストリーム停止.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">再生ストリーム終了.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">デコーダーエラー.</translation>
    </message>
</context>
<context>
    <name>DatabaseBox</name>
    <message>
        <source>Select music to be played:</source>
        <translation type="obsolete">再生する局を選択:</translation>
    </message>
    <message>
        <source>Copy To New Playlist</source>
        <translation>新しいプレイリストにコピーする</translation>
    </message>
    <message>
        <source>Clear the Active Play Queue</source>
        <translation>アクティブなプレイキューをクリアする</translation>
    </message>
    <message>
        <source>Save Back to Playlist Tree</source>
        <translation></translation>
    </message>
    <message>
        <source>Move to Active Play Queue</source>
        <translation>アクティブなプレイキューに移動</translation>
    </message>
    <message>
        <source>Delete This Playlist</source>
        <translation>プレイリスト削除</translation>
    </message>
    <message>
        <source>Rename This Playlist</source>
        <translation>プレイリスト名称変更</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>アクティブプレイキュー</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>全てのマイプレイリスト</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>全てのマイミュージック</translation>
    </message>
    <message>
        <source>Blechy Blech Blah</source>
        <translation></translation>
    </message>
    <message>
        <source>All My Music ~ Loading Music Data </source>
        <translation>全てのマイミュージック ~ 読込中</translation>
    </message>
    <message>
        <source>Loading Music Data</source>
        <translation>ミュージックデータ読込中</translation>
    </message>
    <message>
        <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation>あなたの使用しているテーマに&apos;musictree&apos;エレメントがありません。テーマの作者に連絡してください。&lt;br&gt;&lt;br&gt;次の画面は空になるのでメインメニューに戻ります。</translation>
    </message>
    <message>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <source>Couldn&apos;t create CD</source>
        <translation>CDを作成できませんでした</translation>
    </message>
    <message>
        <source>CD Created</source>
        <translation>CDを作成しました</translation>
    </message>
    <message>
        <source>CD-RW Blanking Progress</source>
        <translation>CD-RW削除中</translation>
    </message>
    <message>
        <source>Create Audio CD from Playlist</source>
        <translation>プレイリストからオーディオCDを作成する</translation>
    </message>
    <message>
        <source>Create MP3 CD from Playlist</source>
        <translation>プレイリストからMP3 CDを作成する</translation>
    </message>
    <message>
        <source>Clear CD-RW Disk</source>
        <translation>CD-RWディスクを消去する</translation>
    </message>
    <message>
        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation>あなたの使用しているテーマに情報ラインがありません。テーマの作者に連絡してください。&lt;br&gt;&lt;br&gt;次の画面は空になるのでメインメニューに戻ります。</translation>
    </message>
    <message>
        <source>Artist:<byte value="x9"/></source>
        <translation>アーチスト: </translation>
    </message>
    <message>
        <source>Album:<byte value="x9"/></source>
        <translation>アルバム:</translation>
    </message>
    <message>
        <source>Title:<byte value="x9"/></source>
        <translation>タイトル:</translation>
    </message>
    <message>
        <source>Length:<byte value="x9"/></source>
        <translation type="unfinished">時間:</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>ジャンル:</translation>
    </message>
    <message>
        <source>Compilation Artist:<byte value="x9"/></source>
        <translation>編集アーチスト:</translation>
    </message>
</context>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Done</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>DB Statistics</source>
        <translation>DB統計</translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>様々なアーティスト</translation>
    </message>
    <message>
        <source>Select an Artist</source>
        <translation>アーチストを選択</translation>
    </message>
    <message>
        <source>Select a Compilation Artist</source>
        <translation>編集アーチストを選択</translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation>アルバムを選択</translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation>ジャンルを選択</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>変更を保存しますか?</translation>
    </message>
    <message>
        <source>Save to Database Only</source>
        <translation>データベースのみ保存</translation>
    </message>
    <message>
        <source>Save to File Only</source>
        <translation>ファイルにのみ保存</translation>
    </message>
    <message>
        <source>Save to File and Database</source>
        <translation>ファイルとデータベースに保存</translation>
    </message>
    <message>
        <source>Exit/Do Not Save</source>
        <translation>保存しないで終了</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Are you sure you want to save the modified metadata to the file?</source>
        <translation>変更をファイルに保存してよろしいですか?</translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>Shuffle Mode</source>
        <translation type="obsolete">シャッフルモード</translation>
    </message>
    <message>
        <source>Repeat Mode</source>
        <translation type="obsolete">リピートモード</translation>
    </message>
    <message>
        <source>Edit Playlist</source>
        <translation type="obsolete">プレイリスト編集</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="obsolete">ビジュアライズ</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">レーティング</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="obsolete">アーティスト</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">タイトル</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">長さ</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">リピート: トラック</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">リピート: 全て</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">再生ストリーム.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">バッファーストリーム.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">ストリーム停止中.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">出力エラー.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">ストリーム停止中.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">再生ストリーム終了.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">デコードエラー.</translation>
    </message>
    <message>
        <source>Shuffle: Intelligent</source>
        <translation type="obsolete">シャッフル: インテリジェント</translation>
    </message>
    <message>
        <source>Shuffle: Random</source>
        <translation type="obsolete">シャッフル: ランダム</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="obsolete">1 シャッフル: 無し</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="obsolete">シャッフル: 無し</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="obsolete">2 リピート: 全て</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="obsolete">2 リピート: トラック</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="obsolete">2 リピート: 無し</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="obsolete">リピート: 無し</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="obsolete">3 プレイリスト編集</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="obsolete">4 ビジュアライズ</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="obsolete">1 シャッフル: スマート</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="obsolete">シャッフル: スマート</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="obsolete">1 シャッフル: ランダム</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="obsolete">シャッフル: ランダム</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="obsolete">プレイリストルート</translation>
    </message>
</context>
<context>
    <name>PlaybackBoxMusic</name>
    <message>
        <source>Edit Playlist</source>
        <translation>プレイリスト編集</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation>ビジュアライズ</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation>3 プレイリスト編集</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation>4 ビジュアライズ</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation>1 シャッフル: スマート</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation>シャッフル: スマート</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation>1 シャッフル: ランダム</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation>シャッフル: ランダム</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation>1 シャッフル: 無し</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation>シャッフル: 無し</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation>2 リピート: 全て</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation>リピート: 全て</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation>2 リピート: トラック</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation>リピート: トラック</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation>2 リピート: 無し</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation>リピート: 無し</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation>プレイリストルート</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation>再生ストリーム.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation>バッファーストリーム.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation>出力エラー.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation>再生ストリーム終了.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation>ストリーム一時停止中.</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <source>kHz</source>
        <translation></translation>
    </message>
    <message>
        <source>ch</source>
        <translation></translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation>ストリーム停止中.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation>デコーダーエラー.</translation>
    </message>
    <message>
        <source>Smart playlists</source>
        <translation>スマートプレイリスト</translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation>全てのトラック</translation>
    </message>
    <message>
        <source>Tracks by current Artist</source>
        <translation>このアーチストのトラック</translation>
    </message>
    <message>
        <source>Tracks from current Album</source>
        <translation>このアルバムのトラック</translation>
    </message>
    <message>
        <source>Tracks from current Genre</source>
        <translation>このジャンルのトラック</translation>
    </message>
    <message>
        <source>Tracks from current Year</source>
        <translation>この年のトラック</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Searching for music files</source>
        <translation>ミュージックファイル検索</translation>
    </message>
    <message>
        <source>Updating music database</source>
        <translation>ミュージックデータベース更新</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation>衝突範囲</translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>各種アーティスト</translation>
    </message>
    <message>
        <source>Ogg Vorbis Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>FLAC Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Directory to hold music</source>
        <translation>ミュージック保存ディレクトリ</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythMusic needs to have write permission to the directory.</source>
        <translation>このディレクトリは必ず存在しなければなりません.MythMusicを実行するユーザーに書き込み権限が必要です.</translation>
    </message>
    <message>
        <source>Audio device</source>
        <translation>オーディオデバイス</translation>
    </message>
    <message>
        <source>Audio Device used for playback.</source>
        <translation>再生時に使用するオーディオデバイス.</translation>
    </message>
    <message>
        <source>CD device</source>
        <translation>CDデバイス</translation>
    </message>
    <message>
        <source>CDRom device used for ripping/playback.</source>
        <translation>リッピング/再生に使用するCDロムデバイス.</translation>
    </message>
    <message>
        <source>Tree Sorting</source>
        <translation>ツリーソート順</translation>
    </message>
    <message>
        <source>Order in which to sort the Music Selection Tree. Possible values are space-separated list of genre, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the actual directory tree.</source>
        <translation type="obsolete">ミュージック選択一覧の順序.スペース区切りで genre, artist, album, titleを指定できます.</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>スクリプトパス</translation>
    </message>
    <message>
        <source>If present this script will be executed after a CD Rip is completed.</source>
        <translation>CDのリッピングが終了したときに実行されます.</translation>
    </message>
    <message>
        <source>Filename Format</source>
        <translation>ファイル名フォーマット</translation>
    </message>
    <message>
        <source>Directory and filename Format used to grab information if no ID3 information is found.</source>
        <translation>ID3情報が見つからないときに使用するディレクトリとファイル名のフォーマット.</translation>
    </message>
    <message>
        <source>Ignore ID3 Tags</source>
        <translation>ID3タグを無視する</translation>
    </message>
    <message>
        <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
        <translation>これをセットするとMythMusicはファイルのID3タグを無視してファイル名からジャンル、アーチスト、アルバム、トラックナンバーとタイトルを取得します。</translation>
    </message>
    <message>
        <source>Automatically lookup CDs</source>
        <translation>CDを自動的に検索する</translation>
    </message>
    <message>
        <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
        <translation>ミュージック選択画面で音楽CDの内容を自動的に表示します。</translation>
    </message>
    <message>
        <source>Use Keyboard/Remote Accelerated Buttons</source>
        <translation>キーボード/リモートアクセラレートボタンを使用する</translation>
    </message>
    <message>
        <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
        <translation>これをセットしないと、矢印キーで機能を選択しなければなりません。</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>エンコーディグ</translation>
    </message>
    <message>
        <source>Ogg Vorbis</source>
        <translation></translation>
    </message>
    <message>
        <source>Lame (MP3)</source>
        <translation></translation>
    </message>
    <message>
        <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
        <translation>CDリッピングに使用するエンコーダー.FLACエンコーダーを使用すると品質は&quot;完璧&quot;です.</translation>
    </message>
    <message>
        <source>File storage location</source>
        <translation>ファイル保存場所</translation>
    </message>
    <message>
        <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
        <translation>既定の音楽の場所。使用できるパラメータは: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / と - です。&apos;-&apos;はセパレーターに置き換えられます。</translation>
    </message>
    <message>
        <source>Token separator</source>
        <translation>トークンセパレータ</translation>
    </message>
    <message>
        <source> - </source>
        <translation></translation>
    </message>
    <message>
        <source>Filename tokens will be separated by this string.</source>
        <translation>ファイル名トークンで文字を区切ります.</translation>
    </message>
    <message>
        <source>Replace &apos; &apos; with &apos;_&apos;</source>
        <translation>&apos; &apos;を&apos;_&apos;に置き換える</translation>
    </message>
    <message>
        <source>If set, whitespace characters in filenames will be replaced with underscore characters.</source>
        <translation>これをセットするとファイル名のスペースを指定した文字に置き換えます.</translation>
    </message>
    <message>
        <source>Paranoia Level</source>
        <translation>パラノイアレベル</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>完全</translation>
    </message>
    <message>
        <source>Faster</source>
        <translation>高速</translation>
    </message>
    <message>
        <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
        <translation>CDリッパーのパラノイアレベル.オーディオに問題が有る場合は早い方に設定して下さい.</translation>
    </message>
    <message>
        <source>Automatically eject CDs after ripping</source>
        <translation>リッピングの後自動的にCDを取り出す</translation>
    </message>
    <message>
        <source>If set, the CD tray will automatically open after the CD has been ripped.</source>
        <translation>セットするとCDリッピングが終了した時に自動的にCDトレイを開きます.</translation>
    </message>
    <message>
        <source>Rating Weight</source>
        <translation>レーティングウェイト</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to your rating of a given track when ordering a group of songs.</source>
        <translation>”スマート”シャッフルモードで使用されます.この設定はトラックのレイティングに影響を与えます.</translation>
    </message>
    <message>
        <source>Play Count Weight</source>
        <translation>プレイカウントウェイト</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
        <translation>&quot;スマート&quot;シャッフルモードで使用されます。再生回数が曲順に影響します。</translation>
    </message>
    <message>
        <source>Last Play Weight</source>
        <translation>ラストプレイウェイト</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
        <translation>&quot;スマート&quot;シャッフルモードで使用されます。再生されてからの時間が曲順に影響します。</translation>
    </message>
    <message>
        <source>Random Weight</source>
        <translation>ランダムウェイト</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
        <translation>&quot;スマート&quot;シャッフルモードで使用されます。</translation>
    </message>
    <message>
        <source>Show Song Ratings</source>
        <translation>ソングレイティングを表示する</translation>
    </message>
    <message>
        <source>Show song ratings on the playback screen.</source>
        <translation>再生スクリーンにソングレイティングを表示する.</translation>
    </message>
    <message>
        <source>List as Shuffled</source>
        <translation>シャッフルリスト</translation>
    </message>
    <message>
        <source>List songs on the playback screen in the order they will be played.</source>
        <translation>再生画面に再生される順に表示する</translation>
    </message>
    <message>
        <source>Show entire music tree</source>
        <translation>ミュージックリスト全体を表示する</translation>
    </message>
    <message>
        <source>If selected, you can navigate your entire music tree from the playing screen.</source>
        <translation>これを選択すると、再生に全ての音楽を表示します。</translation>
    </message>
    <message>
        <source>Play mode</source>
        <translation>プレイモード</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>ノーマル</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>ランダム</translation>
    </message>
    <message>
        <source>Intelligent</source>
        <translation>インテリジェント</translation>
    </message>
    <message>
        <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
        <translation>再生時のシャッフルモード。ノーマル、ランダム、インテリジェント（ランダム）から選択できます。</translation>
    </message>
    <message>
        <source>Delay before Visualizations start (seconds)</source>
        <translation>ビジュアリゼーション開始前の延滞(秒)</translation>
    </message>
    <message>
        <source>If set to 0, visualizations will never automatically start.</source>
        <translation>0にセットすると自動的に開始されません。</translation>
    </message>
    <message>
        <source>Change Visualizer on each song</source>
        <translation>ビジュアリゼーションを曲ごとに変える</translation>
    </message>
    <message>
        <source>Change the visualizer when the song change.</source>
        <translation>曲が変わる後とにビジュアリゼーションを変更します。</translation>
    </message>
    <message>
        <source>Width for Visual Scaling</source>
        <translation>ビジュアリゼーション幅のスケーリング</translation>
    </message>
    <message>
        <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
        <translation>&quot;2&quot;をセットするとビジュアリゼーションは半分のサイズになります。現在はグームのみ有効です。遅いマシンでCPU負荷を減らします。</translation>
    </message>
    <message>
        <source>Height for Visual Scaling</source>
        <translation>ビジュアリゼーション高さのスケーリング</translation>
    </message>
    <message>
        <source>Visualizations</source>
        <translation>ビジュアリゼーション</translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
        <translation>再生中に使用するビジュアリゼーションのリスト。スペース区切りで並べてください。</translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation>モノスコープ</translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation>ステレオスコープ</translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation>スペクトラム</translation>
    </message>
    <message>
        <source>Goom</source>
        <translation>グーム</translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation></translation>
    </message>
    <message>
        <source>Gears</source>
        <translation>ギア</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation>ブランク</translation>
    </message>
    <message>
        <source>Default Rip Quality</source>
        <translation>既定のリッピングクオリティ</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>完璧</translation>
    </message>
    <message>
        <source>Default quality for new CD rips.</source>
        <translation>新規CDリッピングの既定のクオリティ。</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>全体設定</translation>
    </message>
    <message>
        <source>Playback Settings</source>
        <translation>再生設定</translation>
    </message>
    <message>
        <source>Visualization Settings</source>
        <translation>ビジュアリゼーション設定</translation>
    </message>
    <message>
        <source>CD Ripper Settings</source>
        <translation>CDリッピング設定</translation>
    </message>
    <message>
        <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
        <translation>MPEG レイヤー 1/2/3 オーディオ (MAD デコーダー)</translation>
    </message>
    <message>
        <source>music database</source>
        <translation type="obsolete">ミュージックデータベース</translation>
    </message>
    <message>
        <source>cd ripper</source>
        <translation type="obsolete">CDリッパー</translation>
    </message>
    <message>
        <source>

You have no MythMusic tables in your database.</source>
        <translation type="obsolete">

データベースにミュージックテーブルがありません.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll read the documentation</source>
        <translation type="obsolete">はい、ドキュメントを読みます｡</translation>
    </message>
    <message>
        <source>Unknown Artist</source>
        <translation>不明なアーティスト</translation>
    </message>
    <message>
        <source>Unknown Album</source>
        <translation>不明なアルバム</translation>
    </message>
    <message>
        <source>Unknown Genre</source>
        <translation>不明なジャンル</translation>
    </message>
    <message>
        <source>CD -- none</source>
        <translation>CD -- 無し</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>全てのマイミュージック</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Missing database entry: %1</source>
        <translation>データベースに無し: %1</translation>
    </message>
    <message>
        <source> ~ </source>
        <translation></translation>
    </message>
    <message>
        <source>Ooops</source>
        <translation>う！</translation>
    </message>
    <message>
        <source>%1 ~ %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Not Initialized</source>
        <translation>未初期化</translation>
    </message>
    <message>
        <source>oops</source>
        <translation></translation>
    </message>
    <message>
        <source>,%1</source>
        <translation></translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>全てのマイプレイリスト</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>アクティブプレイキュー</translation>
    </message>
    <message>
        <source>Active Play Queue (%1)</source>
        <translation>アクティブプレイキュー (%1)</translation>
    </message>
    <message>
        <source>Something is Wrong</source>
        <translation>問題発生</translation>
    </message>
    <message>
        <source>Visualization requires FFT library</source>
        <translation>ビジュアリゼーションはFFTライブラリが必要です｡</translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation>コンフィギュレーションを実行しましたか?</translation>
    </message>
    <message>
        <source>and</source>
        <translation>と</translation>
    </message>
    <message>
        <source>Use variable bitrates</source>
        <translation>可変ビットレートを使用</translation>
    </message>
    <message>
        <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
        <translation>これをセットすると、MP3エンコーダーは低品質のときを除いて可変ビットレート(VBR)を使用します。Oggエンコーダーは常に可変ビットレートです。</translation>
    </message>
    <message>
        <source>AlbumArt</source>
        <translation>アルバムアート</translation>
    </message>
    <message>
        <source>CD Ripper Settings (part 2)</source>
        <translation>CDリッパーセティング(パート2)</translation>
    </message>
    <message>
        <source>Enable CD Writing.</source>
        <translation>CD書き込み有効。</translation>
    </message>
    <message>
        <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
        <translation>SCSIかIDE-SCSIのCD-R/RWドライブが必要です。</translation>
    </message>
    <message>
        <source>CD-Writer Device</source>
        <translation>CD-R/RWデバイス</translation>
    </message>
    <message>
        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
        <translation>CD書き込みするSCSIデバイスを選択してください。  IDEデバイスがない場合は起動オプションのhdd(又はhdc/hdb)=ide-scsiを試してください</translation>
    </message>
    <message>
        <source>Disk Size</source>
        <translation>ディスクサイズ</translation>
    </message>
    <message>
        <source>650MB/75min</source>
        <translation>650MB/75分</translation>
    </message>
    <message>
        <source>700MB/80min</source>
        <translation>700MB/80分</translation>
    </message>
    <message>
        <source>Default CD Capacity.</source>
        <translation>規定のCD容量。</translation>
    </message>
    <message>
        <source>Enable directories on MP3 Creation</source>
        <translation>MP3作成時にディレクトリを使用する</translation>
    </message>
    <message>
        <source>CD Write Speed</source>
        <translation>CD書き込みスピード</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>1x</source>
        <translation></translation>
    </message>
    <message>
        <source>2x</source>
        <translation></translation>
    </message>
    <message>
        <source>4x</source>
        <translation></translation>
    </message>
    <message>
        <source>8x</source>
        <translation></translation>
    </message>
    <message>
        <source>16x</source>
        <translation></translation>
    </message>
    <message>
        <source>CD Writer speed. Auto will use the recomended speed.</source>
        <translation>CD書き込みスピード。自動は推奨のスピードを使用します。</translation>
    </message>
    <message>
        <source>CD Blanking Type</source>
        <translation>CD削除タイプ</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>高速</translation>
    </message>
    <message>
        <source>Complete</source>
        <translation>完全</translation>
    </message>
    <message>
        <source>Blanking Method. Fast takes 1 minute. Complete can take up to 20 minutes.</source>
        <translation>削除方法。高速は１分かかります。完全は20分かかります。</translation>
    </message>
    <message>
        <source>CD Recording Settings</source>
        <translation>CD記録設定</translation>
    </message>
    <message>
        <source>Artists</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <source>Creating CD File System</source>
        <translation>CDファイルシステムを作成中</translation>
    </message>
    <message>
        <source>Burning CD</source>
        <translation>CD書き込み中</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
        <translation>ミュージックツリーの並べ方。スペース区切りでキーワードを指定してください。使用できるキーワードは genre, splitartist, artist, album, と title です。</translation>
    </message>
    <message>
        <source>CD: %1 ~ %2 - %3</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Ripper</name>
    <message>
        <source>Please select a quality level and check the album information below:</source>
        <translation>クオリティレベルの選択とアルバム情報を確認してください｡</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>完璧</translation>
    </message>
    <message>
        <source>Artist: </source>
        <translation>アーティスト:</translation>
    </message>
    <message>
        <source>Album: </source>
        <translation>アルバム:</translation>
    </message>
    <message>
        <source>Import this CD</source>
        <translation>CD取り込み</translation>
    </message>
    <message>
        <source>Importing CD:
</source>
        <translation>CD取り込み中:
</translation>
    </message>
    <message>
        <source>Copying from CD:
</source>
        <translation>CDからコピー中:
</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>ジャンル:</translation>
    </message>
    <message>
        <source>Ripping...</source>
        <translation>リッピング...</translation>
    </message>
    <message>
        <source>Multi-Artist?</source>
        <translation>複数のアーチスト?</translation>
    </message>
    <message>
        <source>Switch Titles &amp;&amp; Artists</source>
        <translation>タイトルとアーチストを交換</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>時間</translation>
    </message>
</context>
<context>
    <name>SmartPLCriteriaRow</name>
    <message>
        <source>Select an Artist</source>
        <translation>アーチストを選択</translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation>アルバムを選択</translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation>ジャンルを選択</translation>
    </message>
    <message>
        <source>Select a Title</source>
        <translation>タイトルを選択</translation>
    </message>
</context>
<context>
    <name>SmartPLOrderByDialog</name>
    <message>
        <source>Order By Fields</source>
        <translation>フィールド順</translation>
    </message>
    <message>
        <source>1 Add</source>
        <translation>1 追加</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <source>2 Delete</source>
        <translation>2 削除</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>3 Move Up</source>
        <translation>3 上に移動</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>上に移動</translation>
    </message>
    <message>
        <source>4 Move Down</source>
        <translation>4 下に移動</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>下に移動</translation>
    </message>
    <message>
        <source>5 Ascending</source>
        <translation>5 昇順</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation>昇順</translation>
    </message>
    <message>
        <source>6 Descending</source>
        <translation>6 降順</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>昇順</translation>
    </message>
    <message>
        <source>7 OK</source>
        <translation>7 決定</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>決定</translation>
    </message>
</context>
<context>
    <name>SmartPLResultViewer</name>
    <message>
        <source>Smart Playlist Result Viewer</source>
        <translation>スマートプレイリストビューワー</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>ID</source>
        <translation></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <source>Track No.</source>
        <translation>トラックNo.</translation>
    </message>
</context>
<context>
    <name>SmartPlaylistDialog</name>
    <message>
        <source>Smart Playlists</source>
        <translation>スマートプレイリスト</translation>
    </message>
    <message>
        <source>1 Select</source>
        <translation>1 選択</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>選択</translation>
    </message>
    <message>
        <source>2 New</source>
        <translation>2 新規</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <source>3 Edit</source>
        <translation>3 編集</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>4 Delete</source>
        <translation>4 削除</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this SmartPlaylist?</source>
        <translation>このスマートプレイリストを削除してよろしいですか?</translation>
    </message>
</context>
<context>
    <name>SmartPlaylistEditor</name>
    <message>
        <source>Smart Playlist Editor</source>
        <translation>スマートプレイリスト編集</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>カテゴリー:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>タイトル:</translation>
    </message>
    <message>
        <source>Match</source>
        <translation>検索方法</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全て</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>どれか</translation>
    </message>
    <message>
        <source>Of The Following Conditions</source>
        <translation>下の条件に一致</translation>
    </message>
    <message>
        <source>Order By:</source>
        <translation>並び順:</translation>
    </message>
    <message>
        <source>Matches:</source>
        <translation>一致結果:</translation>
    </message>
    <message>
        <source>Limit:</source>
        <translation>リミット:</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Show Results</source>
        <translation>結果を表示する</translation>
    </message>
    <message>
        <source>Smart Playlist Categories</source>
        <translation>スマートプレイリストのカテゴリー</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新しいカテゴリー</translation>
    </message>
    <message>
        <source>Delete Category</source>
        <translation>カテゴリーを削除</translation>
    </message>
    <message>
        <source>Rename Category</source>
        <translation>カテゴリーの名前を変更</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this Category?</source>
        <translation>このカテゴリーを削除してよろしいですか?</translation>
    </message>
    <message>
        <source>It will also delete any Smart Playlists belonging to this category.</source>
        <translation>関連するスマートプレイリストも削除されます。</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Please Wait...</source>
        <translation>お待ちください ...</translation>
    </message>
    <message>
        <source>Track Information</source>
        <translation>トラック情報</translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation>アーチスト:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>アルバム:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>タイトル:</translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation>ジャンル:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>年:</translation>
    </message>
    <message>
        <source>Track No.:</source>
        <translation>トラックNo:</translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation>レイティング:</translation>
    </message>
    <message>
        <source>Play Count:</source>
        <translation>プレイカウント:</translation>
    </message>
    <message>
        <source>Last Play:</source>
        <translation>ラストプレイ:</translation>
    </message>
    <message>
        <source>Compilation:</source>
        <translation>編集:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>ファイル名:</translation>
    </message>
</context>
</TS>
